diff --git a/Library/Homebrew/cask/lib/hbc/utils.rb b/Library/Homebrew/cask/lib/hbc/utils.rb
index 116cb20956d54bb72cc78683674d383d13c18acd..b442efd2f2d7521ee4b4a800860ba87a6d012762 100644
--- a/Library/Homebrew/cask/lib/hbc/utils.rb
+++ b/Library/Homebrew/cask/lib/hbc/utils.rb
@@ -117,7 +117,7 @@ module Hbc
 
     def self.error_message_with_suggestions
       <<-EOS.undent
-        Follow the instuctions here:
+        Follow the instructions here:
           #{Formatter.url(PREBUG_URL)}
 
         If this doesn鈥檛 fix the problem, please report this bug:
diff --git a/Library/Homebrew/cmd/unpack.rb b/Library/Homebrew/cmd/unpack.rb
index 6f4caea18999b5d9a43441833209ffb88d91b17e..4e6584e70b6b238dff0b5d43b56f6db453a2bde6 100644
--- a/Library/Homebrew/cmd/unpack.rb
+++ b/Library/Homebrew/cmd/unpack.rb
@@ -6,7 +6,7 @@
 #:    If `--patch` is passed, patches for <formulae> will be applied to the
 #:    unpacked source.
 #:
-#:    If `--git` is passed, a Git repository will be initalized in the unpacked
+#:    If `--git` is passed, a Git repository will be initialized in the unpacked
 #:    source. This is useful for creating patches for the software.
 
 require "stringio"
diff --git a/Library/Homebrew/dev-cmd/audit.rb b/Library/Homebrew/dev-cmd/audit.rb
index 96b9870c652209f291f91d069e3cef2cd18b57d6..3c190176304116baa75f5a206f76ccc0e79a59da 100644
--- a/Library/Homebrew/dev-cmd/audit.rb
+++ b/Library/Homebrew/dev-cmd/audit.rb
@@ -11,7 +11,7 @@
 #:    connection are run.
 #:
 #:    If `--new-formula` is passed, various additional checks are run that check
-#:    if a new formula is eligable for Homebrew. This should be used when creating
+#:    if a new formula is eligible for Homebrew. This should be used when creating
 #:    new formulae and implies `--strict` and `--online`.
 #:
 #:    If `--display-cop-names` is passed, the RuboCop cop name for each violation
diff --git a/Library/Homebrew/download_strategy.rb b/Library/Homebrew/download_strategy.rb
index 05776824645993c036f915b2e1dfc60377b34255..63b821cebf1392ae7d09294f1c521156c76dc8c4 100644
--- a/Library/Homebrew/download_strategy.rb
+++ b/Library/Homebrew/download_strategy.rb
@@ -20,7 +20,7 @@ class AbstractDownloadStrategy
   def fetch
   end
 
-  # Supress output
+  # Suppress output
   def shutup!
     @shutup = true
   end
diff --git a/Library/Homebrew/formula.rb b/Library/Homebrew/formula.rb
index f1d907b7a583d8012e9f3703d0f43278b98cfcc8..ab05548a8ea17522ad03d9940394255cacde717f 100644
--- a/Library/Homebrew/formula.rb
+++ b/Library/Homebrew/formula.rb
@@ -1599,7 +1599,7 @@ class Formula
     HOMEBREW_LIBRARY_PATH.join("test", "fixtures", file)
   end
 
-  # This method is overriden in {Formula} subclasses to provide the installation instructions.
+  # This method is overridden in {Formula} subclasses to provide the installation instructions.
   # The sources (from {.url}) are downloaded, hash-checked and
   # Homebrew changes into a temporary directory where the
   # archive was unpacked or repository cloned.
diff --git a/docs/brew.1.html b/docs/brew.1.html
index 931daf936aaf92f1819ae2d864e9d8b05c690d1a..7af76e6f094477f0c5b7952e5d91c0537aeb4fbe 100644
--- a/docs/brew.1.html
+++ b/docs/brew.1.html
@@ -374,7 +374,7 @@ be created in the directory named by <code>&lt;path></code> instead.</p>
 <p>If <code>--patch</code> is passed, patches for <var>formulae</var> will be applied to the
 unpacked source.</p>
 
-<p>If <code>--git</code> is passed, a Git repository will be initalized in the unpacked
+<p>If <code>--git</code> is passed, a Git repository will be initialized in the unpacked
 source. This is useful for creating patches for the software.</p></dd>
 <dt><code>unpin</code> <var>formulae</var></dt><dd><p>Unpin <var>formulae</var>, allowing them to be upgraded by <code>brew upgrade</code>. See also
 <code>pin</code>.</p></dd>
@@ -447,7 +447,7 @@ style checks.</p>
 connection are run.</p>
 
 <p>If <code>--new-formula</code> is passed, various additional checks are run that check
-if a new formula is eligable for Homebrew. This should be used when creating
+if a new formula is eligible for Homebrew. This should be used when creating
 new formulae and implies <code>--strict</code> and <code>--online</code>.</p>
 
 <p>If <code>--display-cop-names</code> is passed, the RuboCop cop name for each violation
diff --git a/manpages/brew-cask.1 b/manpages/brew-cask.1
index 0b0776595441e4f8a1d29ebaa6e145cdd76263e0..a14c7521ab70d0fe24712ff56d9abb73f54aba74 100644
--- a/manpages/brew-cask.1
+++ b/manpages/brew-cask.1
@@ -1,7 +1,7 @@
 .\" generated with Ronn/v0.7.3
 .\" http://github.com/rtomayko/ronn/tree/0.7.3
 .
-.TH "BREW\-CASK" "1" "October 2016" "Homebrew" "brew-cask"
+.TH "BREW\-CASK" "1" "November 2016" "Homebrew" "brew-cask"
 .
 .SH "NAME"
 \fBbrew\-cask\fR \- a friendly binary installer for macOS
diff --git a/manpages/brew.1 b/manpages/brew.1
index 1205c888f01dfd8a776b94297671f6be17d395f4..fb528c0f411672f26084aa79555abffd4d2f43b1 100644
--- a/manpages/brew.1
+++ b/manpages/brew.1
@@ -1,7 +1,7 @@
 .\" generated with Ronn/v0.7.3
 .\" http://github.com/rtomayko/ronn/tree/0.7.3
 .
-.TH "BREW" "1" "October 2016" "Homebrew" "brew"
+.TH "BREW" "1" "November 2016" "Homebrew" "brew"
 .
 .SH "NAME"
 \fBbrew\fR \- The missing package manager for macOS
@@ -518,7 +518,7 @@ Unpack the source files for \fIformulae\fR into subdirectories of the current wo
 If \fB\-\-patch\fR is passed, patches for \fIformulae\fR will be applied to the unpacked source\.
 .
 .IP
-If \fB\-\-git\fR is passed, a Git repository will be initalized in the unpacked source\. This is useful for creating patches for the software\.
+If \fB\-\-git\fR is passed, a Git repository will be initialized in the unpacked source\. This is useful for creating patches for the software\.
 .
 .TP
 \fBunpin\fR \fIformulae\fR
@@ -626,7 +626,7 @@ If \fB\-\-strict\fR is passed, additional checks are run, including RuboCop styl
 If \fB\-\-online\fR is passed, additional slower checks that require a network connection are run\.
 .
 .IP
-If \fB\-\-new\-formula\fR is passed, various additional checks are run that check if a new formula is eligable for Homebrew\. This should be used when creating new formulae and implies \fB\-\-strict\fR and \fB\-\-online\fR\.
+If \fB\-\-new\-formula\fR is passed, various additional checks are run that check if a new formula is eligible for Homebrew\. This should be used when creating new formulae and implies \fB\-\-strict\fR and \fB\-\-online\fR\.
 .
 .IP
 If \fB\-\-display\-cop\-names\fR is passed, the RuboCop cop name for each violation is included in the output\.
diff --git a/Library/Homebrew/migrator.rb b/Library/Homebrew/migrator.rb
index fe480cd3b603aa755366958b91dd1b98637bbc71..a80cf0c594227ceda77fed298f993a735946b76c 100644
--- a/Library/Homebrew/migrator.rb
+++ b/Library/Homebrew/migrator.rb
@@ -165,7 +165,7 @@ class Migrator
     rescue Interrupt
       ignore_interrupts { backup_oldname }
     rescue Exception => e
-      onoe "Error occured while migrating."
+      onoe "Error occurred while migrating."
       puts e
       puts e.backtrace if ARGV.debug?
       puts "Backuping..."
@@ -293,7 +293,7 @@ class Migrator
     end
   end
 
   # Backup everything if errors occured while migrating.
   def backup_oldname
     unlink_oldname_opt
     unlink_oldname_cellar
@@ -293,7 +293,7 @@ class Migrator
   end
 
-  # Backup everything if errors occured while migrating.
+  # Backup everything if errors occurred while migrating.
   def backup_oldname
     unlink_oldname_opt